from setuptools import setup, find_packages

setup(
    name="tour_agent",
    version="0.1",
    description="A Python library for managing tour packages and clients.",
    author="Asilbek Sadullayev",
    packages=find_packages(),
    install_requires=[],
    python_requires=">=3.8",
)
